#include "util.h"

#include <cstddef>

#include <opencv2/core.hpp>
#include <opencv2/core/mat.hpp>
#include <opencv2/opencv.hpp>

#include <ArmarXCore/core/exceptions/local/ExpressionException.h>
#include <ArmarXCore/core/logging/Logging.h>

namespace armarx::navigation
{
    void
    dumpToFile(const Eigen::MatrixXf& grid)
    {
        ARMARX_INFO << "Dumping to file.";
        ARMARX_INFO << "Shape: " << grid.rows() << ", " << grid.cols();

        // pedantic checks to prevent underflow below
        ARMARX_CHECK_GREATER(grid.rows(), 0);
        ARMARX_CHECK_GREATER(grid.cols(), 0);

        const cv::Size size(static_cast<int>(grid.rows()), static_cast<int>(grid.cols()));

        cv::Mat1f mat(size);

        for (int r = 0; r < grid.rows(); r++)
        {
            for (int c = 0; c < grid.cols(); c++)
            {
                mat(cv::Point(r, c)) = grid(r, c);
            }
        }


        cv::imwrite("/tmp/grid.exr", mat);
    }
} // namespace armarx::navigation
